pixtopix: Coordinate transformation to/from drizzled images — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »

# pixtopix: Coordinate transformation to/from drizzled images

This task allows a user to perform coordinate transformations with the full WCS and distortion model to and from drizzled image positions. This task serves as a replacement for the STSDAS.dither task ‘tran’.

pixtosky - A module to perform coordinate transformation from pixel coordinates
  in one image to pixel coordinates in another frame
License:
  http://www.stsci.edu/resources/software_hardware/pyraf/LICENSE

## PARAMETERS

inimage : str
  full filename with path of input image, an extension name [‘sci’,1] should be provided if input is a multi-extension FITS file
outimage : str
  full filename with path of output image, an extension name [‘sci’,1] should be provided if output is a multi-extension FITS file
direction : str
  Direction of transform (forward or backward). The ‘forward’ transform takes the pixel positions (assumed to be from the ‘input’ image) and determines their position in the ‘output’ image. The ‘backward’ transform converts the pixel positions (assumed to be from the ‘output’ image) into pixel positions in the ‘input’ image.

## Optional Parameters

x : float, optional
  X position from image
y : float, optional
  Y position from image
coords : str, optional
  full filename with path of file with starting x,y coordinates
colnames : str, optional
  comma separated list of column names from ‘coords’ files containing x,y coordinates, respectively. Will default to first two columns if None are specified. Column names for ASCII files will use ‘c1’,’c2’,... convention.
separator : str, optional
  non-blank separator used as the column delimiter in the coords file
precision : int, optional
  Number of floating-point digits in output values
output : str, optional
  Name of output file with results, if desired
verbose : bool
  Print out full list of transformation results (default: False)

## RETURNS

outx : float
  X position of transformed pixel. If more than 1 input value, then it will be a numpy array.
outy : float
  Y position of transformed pixel. If more than 1 input value, then it will be a numpy array.

## NOTES

This module performs a full distortion-corrected coordinate transformation based on all WCS keywords and any recognized distortion keywords from the input image header.

## Usage

It can be called from within Python using the syntax:

    >>> from drizzlepac import pixtopix
    >>> outx,outy = pixtopix.tran("input_flt.fits[sci,1]",
                    "output_drz.fits[sci,1],"forward",100,100)

## EXAMPLES

1. The following command will transform the position 256,256 from

     ‘input_flt.fits[sci,1]’ into a position on the output image ‘output_drz.fits[sci,1]’ using:

         >>> from drizzlepac import pixtopix
         >>> outx,outy = pixtopix.tran("input_file_flt.fits[sci,1]",
                     "output_drz.fits[sci,1],"forward", 256,256)

2. The set of X,Y positions from ‘output_drz.fits[sci,1]’ stored as

     the 3rd and 4th columns from the ASCII file ‘xy_sci1.dat’ will be transformed into pixel positions from ‘input_flt.fits[sci,1]’ and written out to ‘xy_flt1.dat’ using:

         >>> from drizzlepac import pixtopix
         >>> x,y = pixtopix.tran("input_flt.fits[sci,1]", "output_drz.fits[sci,1]",
                 "backward", coords='xy_sci1.dat', colnames=['c3','c4'],
                 output="xy_flt1.dat")

`drizzlepac.pixtopix.` `tran`(inimage, outimage, direction='forward', x=None, y=None, coords=None, colnames=None, separator=None, precision=6, output=None, verbose=True)

  Primary interface to perform coordinate transformations in pixel coordinates between 2 images using STWCS and full distortion models read from each image’s header.

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »